@@ -7,16 +7,17 @@
 # generated, with theoretical gamma superimposed.
 ###############################################################################
 igamma <- function(u = runif(1), shape, rate = 1, scale = 1/rate,
-                   minPlotQuantile  = 0, 
-                   maxPlotQuantile  = 0.95,
-                   plot             = TRUE,
-                   showCDF          = TRUE,
-                   showPDF          = FALSE,
-                   showECDF         = FALSE,
-                   show             = NULL,
-                   plotDelay        = 0,
-                   maxPlotTime      = 30,
-                   resetRowsMargins = TRUE)
+                   minPlotQuantile = 0, 
+                   maxPlotQuantile = 0.95,
+                   plot            = TRUE,
+                   showCDF         = TRUE,
+                   showPDF         = FALSE,
+                   showECDF        = FALSE,
+                   show            = NULL,
+                   plotDelay       = 0,
+                   maxPlotTime     = 30,
+                   showTitle       = TRUE,
+                   respectLayout   = TRUE)
 {
   #############################################################################
 
@@ -66,8 +67,10 @@ igamma <- function(u = runif(1), shape, rate = 1, scale = 1/rate,
       stop("when 'show' is not a binary vector, it must be an integer in [0,7]")
   }
 
-  if (!is.logical(resetRowsMargins) || length(resetRowsMargins) != 1)
-    stop("'resetRowsMargins' must be a single logical value")
+  if (!is.logical(showTitle) || length(showTitle) != 1)
+    stop("'showTitle' must be a single logical value")
+  if (!is.logical(respectLayout) || length(respectLayout) != 1)
+    stop("'respectLayout' must be a single logical value")
 
   if (!is.numeric(plotDelay) || length(plotDelay) != 1 || plotDelay < 0)
     stop("'plotDelay' must be a numeric value (in secs) >= 0")
@@ -169,11 +172,28 @@ igamma <- function(u = runif(1), shape, rate = 1, scale = 1/rate,
   }
 
   # use sum to determine how many plot "shows" are TRUE ==> set # rows
-  rows <- sum(showCDF, showPDF, showECDF)
-  par(mfrow = c(rows, 1))
+  minPlots  <- sum(showCDF, showPDF, showECDF)
+
+  if (respectLayout) {
+    # try to respect user's previously defined par(mfrow) or par(mfcol) if 
+    # sufficient to show all plots; if not, display a warning message
+    userPlots <- prod(par("mfrow"))
+    if (userPlots < minPlots) {
+      msg <- paste('Cannot display the requested ', minPlots, 
+              ' plots simultaneously because layout is set for ', userPlots, 
+              ' plot', if (userPlots > 1) 's. ' else '. ',
+              'Please use \'par\' to set layout appropriately, e.g., ',
+              'par(mfrow = c(', minPlots, ',1)) or ', 
+              'par(mfcol = c(1,', minPlots, ')).', sep = "")
+      warning(msg)
+    }
+  } else {
+    # force the layout sufficient to show only these plots
+    par(mfrow = c(minPlots, 1))  # minPlots rows, 1 column
+  }
 
   # set default margins for plots
-  botMar <- if (rows > 1) 4.1 else 5.1
+  botMar <- if (minPlots > 1) 4.1 else 5.1
   par(mar = c(botMar, 4.1, 2.1, 1.5))
 
   # set color for plotting variates / estimated curves
@@ -328,7 +348,7 @@ igamma <- function(u = runif(1), shape, rate = 1, scale = 1/rate,
     segments(toX,   0, toX,   1, lty = "dotted", xpd = NA)
 
     # draw the title
-    title(titleStr, cex.main = 0.975)
+    if (showTitle) title(titleStr, cex.main = 0.975)
 
     # try to find appropriate x-value to draw u's and u-points...
     # by trial and error, decreasing by -0.02*plot_range seems to work...
@@ -444,7 +464,7 @@ igamma <- function(u = runif(1), shape, rate = 1, scale = 1/rate,
          xlim = c(fromX, toX), ylim = c(0, pdfYMax))
 
     # draw the title, only if not already drawn by showCDF above
-    if (showCDF == FALSE) title(titleStr, cex.main = 0.975)
+    if (showTitle && showCDF == FALSE) title(titleStr, cex.main = 0.975)
 
     if (!is.null(xVals))  # plotting variates
     {
@@ -545,14 +565,16 @@ igamma <- function(u = runif(1), shape, rate = 1, scale = 1/rate,
     segments(toX,   0, toX,   1, lty = "dotted", xpd = FALSE)
 
     # draw the title
-    if (showCDF == FALSE && showPDF == FALSE) title(titleStr, cex.main = 0.975)
+    if (showTitle && showCDF == FALSE && showPDF == FALSE) {
+      title(titleStr, cex.main = 0.975)
+    }
 
   }  # if (showECDF == TRUE)
 
   #############################################################################
 
   # reset display, margins, and warnings
-  if (resetRowsMargins) {
+  if (!respectLayout) {
     par(mfrow = c(1, 1))
     par(mar = c(5.1, 4.1, 4.1, 2.1))
   }
